"""ZenquotesPy
=====
ZenquotesPy is a lightweight Python package that provides easy access to motivational and inspirational quotes from the ZenQuotes.io API.
"""

from .main import random
from .main import today
from .main import get_bulk_quotes
from .main import image
from .main import attribution
